@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 # ABSTRACT: Map::Tube::Nuremberg - interface to the Nuremberg U-Bahn map
 
@@ -31,13 +31,17 @@ Map::Tube::Nuremberg - Map::Tube::Nuremberg - interface to the Nuremberg U-Bahn
 
 =head1 VERSION
 
-version 0.06
+version 0.08
 
 =head1 DESCRIPTION
 
 It currently provides functionality to find the shortest route between
 the two given stations. The map contains currently only (U-Bahn) subway stations.
 
+Hint: 
+ID in JSON-File is VGN-Kennung as used in https://opendata.vag.de/dataset/haltestellen-id-geodaten. 
+If Station-ID is not unique, the VGN-Kennung for U-Bahn is used.
+
 =head1 CONSTRUCTOR
 
     use Map::Tube::Nuremberg;
